/*
 * BettingSystem
 *
 * 2002-Apr-05
 *
 * This code licensed under the GPL, see http://www.gnu.org/licenses/gpl.txt
 *
 */
 
package net.bluebones.Gambler;

import java.util.LinkedList;

/**
 * Command-line program to check profit from a set of bets on the same 'race'
 *  and how much should be bet on each 'runner'.
 *
 * @version 1.0
 * @author Thomas Baker
 */
public class BettingSystem {
	
	/** 
	 * Flag for verbose mode where numbers are written out to full
	 *  number of decimal places
	 */	
	private static boolean verboseMode = false;

	/**
	 * Main routine of program
	 */
	public static void main(String[] args) {

		final int totalStake = 1;
		LinkedList input = new LinkedList();
		
		if (args.length == 0) {
			System.err.println("Usage: BettingSystem "
			    + "<-v for maximum decimal places> <odds> ...");
			System.err.println(
			    "Example: BettingSystem 7/2 3/1 1/3 .5");
			System.exit(0);	
		}
		
		int startAt = 0;
		
		if (args[0].equals("-v")) {
			verboseMode = true;
			startAt = 1;
		}
		
		for (int i = startAt; i < args.length; i++) {
			input.add(args[i]);
		}
		
		double[] odds = new double[input.size()];
		String[] textOdds = new String[input.size()];
		double[] reciprocal = new double[input.size()];
		double[] stake = new double[input.size()];
		double winnings = 0;
		double[] percentage = new double[input.size()];
		double total = 0;
	
		for (int i = 0; i < input.size(); i++) {
			textOdds[i] = (String) input.get(i);
			odds[i] = OddsParser.parse(textOdds[i]);
			reciprocal[i] = 1 / (odds[i] + 1);
			total += reciprocal[i];
		}
		
		System.out.println();
		
		for (int i = 0; i < input.size(); i++) {
			percentage[i] = (reciprocal[i] / total);
			stake[i] = totalStake * percentage[i];
			winnings = (odds[i] * stake[i]) 
			    + stake[i] - totalStake;
			    
			System.out.println("On item with odds " + textOdds[i] 
			    + " bet " + formatPercentage(percentage[i])
			    + " of total stake");
			    
		}
		
		System.out.println();
		System.out.println("Profit: " + formatPercentage(winnings)
		    + " of total stake");
	
	}
	
	/**
	 * Formats figure for presentation according to whether program is in 
	 * verbose mode or not
	 *
	 * @params d figure to format for presentation
	 */
	private static String formatPercentage(double d) {
	
		String s = new Double(d).toString();
	
		if (verboseMode) {
			return s;
		} else {
			/* Chomp it down to 5 characters */
			return (s.length() > 5 ? s.substring(0, 5) : s);
		}
		
	}

}